Mailinglist Archive: opensuse-commit (794 mails)

< Previous Next >
commit kasumi for openSUSE:Factory
  • From: root@xxxxxxxxxxxxxxx (h_root)
  • Date: Wed, 02 Sep 2009 19:05:11 +0200
  • Message-id: <20090902170511.BD7FC6484@xxxxxxxxxxxxxxx>

Hello community,

here is the log from the commit of package kasumi for openSUSE:Factory
checked in at Wed Sep 2 19:05:11 CEST 2009.


--------
--- kasumi/kasumi.changes 2009-06-10 08:03:16.000000000 +0200
+++ kasumi/kasumi.changes 2009-07-30 11:52:11.000000000 +0200
@@ -1,0 +2,12 @@
+Thu Jul 30 11:30:42 CEST 2009 - tiwai@xxxxxxx
+
+- updated to version 2.5:
+ * Remove "SIKU" conjugation.
+ * Kill duplicated Ikuya Awashiro in man page
+ * Added some word type subcategories
+ * Fix misc warnings
+ * Fix paddings in windows
+ * Fix minimum size of columns in the word list view
+ * Other code clean ups
+
+-------------------------------------------------------------------

calling whatdependson for head-i586


Old:
----
kasumi-2.4.tar.bz2

New:
----
kasumi-2.5.tar.bz2

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ kasumi.spec ++++++
--- /var/tmp/diff_new_pack.cS5a0U/_old 2009-09-02 19:04:55.000000000 +0200
+++ /var/tmp/diff_new_pack.cS5a0U/_new 2009-09-02 19:04:55.000000000 +0200
@@ -1,5 +1,5 @@
#
-# spec file for package kasumi (Version 2.4)
+# spec file for package kasumi (Version 2.5)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
@@ -24,7 +24,7 @@
Group: System/I18n/Japanese
AutoReqProv: on
Provides: locale(anthy:ja)
-Version: 2.4
+Version: 2.5
Release: 1
Url: http://kasumi.sourceforge.jp/
Source0: kasumi-%{version}.tar.bz2

++++++ kasumi-2.4.tar.bz2 -> kasumi-2.5.tar.bz2 ++++++
++++ 9472 lines of diff (skipped)
++++ retrying with extended exclude list
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/ChangeLog new/kasumi-2.5/ChangeLog
--- old/kasumi-2.4/ChangeLog 2009-01-21 02:15:31.000000000 +0100
+++ new/kasumi-2.5/ChangeLog 2009-07-21 11:01:14.000000000 +0200
@@ -1,3 +1,48 @@
+2009-07-29 Takuro Ashie <ashie@xxxxxxxxxxxxxx>
+
+ * preparation for release (ver 2.5)
+
+2009-07-21 Takuro Ashie <ashie@xxxxxxxxxxxxxx>
+
+ * fix:
+ - Fix paddings in the KasumiAddWindow.
+
+2009-07-16 Takuro Ashie <ashie@xxxxxxxxxxxxxx>
+
+ * fix:
+ - Use stock objects for buttons on KasumiAddWindow.
+ - Remove neeldless key accelerators for KasumiAddWindow.
+
+2009-07-16 Takuro Ashie <ashie@xxxxxxxxxxxxxx>
+
+ * fix:
+ - Fix paddings in the main window.
+ - Fix minimum size of columns in the word list view.
+ - Remove needless key accelerators in main window.
+ Use mnemonic instead.
+ - Remove some needless codes.
+
+2009-07-13 Takuro Ashie <ashie@xxxxxxxxxxxxxx>
+
+ * fix:
+ - Fix a compile time warning.
+ - Rename some strang variable names.
+
+2009-07-13 Takuro Ashie <ashie@xxxxxxxxxxxxxx>
+
+ * enhancement:
+ - Added some word type subcategories. Thanks to Jun Oizumi.
+
+2009-06-25 Takuro Ashie <ashie@xxxxxxxxxxxxxx>
+
+ * fix
+ - Kill duplicated Ikuya Awashiro in man page! Thanks to Jun Oizumi.
+
+2009-06-25 Takuro Ashie <ashie@xxxxxxxxxxxxxx>
+
+ * fix
+ - Remove "SIKU" conjugation. Thanks to Jun Oizumi.
+
2009-01-29 Takuro Ashie <ashie@xxxxxxxxxxxxxx>

* preparation for release (ver 2.4)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/KasumiMainWindow.cxx new/kasumi-2.5/KasumiMainWindow.cxx
--- old/kasumi-2.4/KasumiMainWindow.cxx 2009-01-20 06:34:08.000000000 +0100
+++ new/kasumi-2.5/KasumiMainWindow.cxx 2009-07-16 10:04:20.000000000 +0200
@@ -68,54 +68,48 @@

void KasumiMainWindow::createWindow()
{
-// GtkWidget *mWindow;
GtkWidget *vbox1;
-// GtkWidget *scrolledwindow1;
-// GtkWidget *mWordListView;
GtkWidget *vbox2;
GtkWidget *label1;
GtkWidget *hbox1;
-// GtkWidget *mSpellingRadio;
GSList *mSpellingRadio_group = NULL;
-// GtkWidget *mSoundRadio;
- GtkWidget *hbox2;
-// GtkWidget *mSearchEntry;
- GtkWidget *alignment6;
+ GtkWidget *alignment;
GtkWidget *hbuttonbox1;
-// GtkWidget *mSaveButton;
-// GtkWidget *mAddButton;
-// GtkWidget *mRemoveButton;
-// GtkWidget *mChangeModeButton;
-// GtkWidget *mQuitButton;
- GtkAccelGroup *accel_group;
-
- accel_group = gtk_accel_group_new ();

mWindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+ gtk_widget_set_size_request(mWindow, -1, 400);
gtk_window_set_title (GTK_WINDOW (mWindow), _("Kasumi"));

vbox1 = gtk_vbox_new (FALSE, 0);
+ gtk_container_set_border_width(GTK_CONTAINER(vbox1), 6);
gtk_widget_show (vbox1);
gtk_container_add (GTK_CONTAINER (mWindow), vbox1);

mScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
+ gtk_container_set_border_width(GTK_CONTAINER(mScrolledWindow), 6);
gtk_widget_show (mScrolledWindow);
gtk_box_pack_start (GTK_BOX (vbox1), mScrolledWindow, TRUE, TRUE, 0);
gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (mScrolledWindow),
GTK_SHADOW_IN);
+ gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(mScrolledWindow),
+ GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

mWordListView = gtk_tree_view_new ();
gtk_widget_show (mWordListView);
gtk_container_add (GTK_CONTAINER (mScrolledWindow), mWordListView);

vbox2 = gtk_vbox_new (FALSE, 0);
+ gtk_container_set_border_width(GTK_CONTAINER(vbox2), 6);
gtk_widget_show (vbox2);
gtk_box_pack_start (GTK_BOX (vbox1), vbox2, FALSE, FALSE, 0);

- label1 = gtk_label_new (_("search"));
+ label1 = gtk_label_new (NULL);
+ gtk_label_set_markup (GTK_LABEL (label1), _("<b>Search:</b>"));
gtk_widget_show (label1);
gtk_box_pack_start (GTK_BOX (vbox2), label1, FALSE, FALSE, 0);
gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);
- gtk_misc_set_padding (GTK_MISC (label1), 10, 0);
+ gtk_misc_set_padding (GTK_MISC (label1), 4, 4);
+
+

hbox1 = gtk_hbox_new (FALSE, 0);
gtk_widget_show (hbox1);
@@ -133,70 +127,45 @@
gtk_radio_button_set_group (GTK_RADIO_BUTTON (mSoundRadio),
mSpellingRadio_group);
mSpellingRadio_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON
(mSoundRadio));

- hbox2 = gtk_hbox_new (FALSE, 0);
- gtk_widget_show (hbox2);
- gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
+ alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+ gtk_widget_show (alignment);
+ gtk_box_pack_start (GTK_BOX (vbox2), alignment, FALSE, FALSE, 6);
+ gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 18, 0);

mSearchEntry = gtk_entry_new ();
gtk_widget_show (mSearchEntry);
- gtk_box_pack_start (GTK_BOX (hbox2), mSearchEntry, TRUE, TRUE, 40);
+ gtk_container_add (GTK_CONTAINER (alignment), mSearchEntry);

- alignment6 = gtk_alignment_new (0.5, 0.5, 1, 1);
- gtk_widget_show (alignment6);
- gtk_box_pack_start (GTK_BOX (vbox1), alignment6, FALSE, FALSE, 8);
- gtk_alignment_set_padding (GTK_ALIGNMENT (alignment6), 0, 0, 12, 12);
+ alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+ gtk_widget_show (alignment);
+ gtk_box_pack_start (GTK_BOX (vbox1), alignment, FALSE, FALSE, 6);
+ gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 6, 6);

hbuttonbox1 = gtk_hbutton_box_new ();
gtk_widget_show (hbuttonbox1);
- gtk_container_add (GTK_CONTAINER (alignment6), hbuttonbox1);
- gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1),
GTK_BUTTONBOX_SPREAD);
+ gtk_container_add (GTK_CONTAINER (alignment), hbuttonbox1);
+ gtk_box_set_spacing(GTK_BOX(hbuttonbox1), 6);
+ gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_END);

mSaveButton = gtk_button_new_from_stock ("gtk-save");
gtk_widget_show (mSaveButton);
- gtk_container_add (GTK_CONTAINER (hbuttonbox1), mSaveButton);
+ gtk_box_pack_start (GTK_BOX (hbuttonbox1), mSaveButton, FALSE, TRUE, 0);
GTK_WIDGET_SET_FLAGS (mSaveButton, GTK_CAN_DEFAULT);
- gtk_widget_add_accelerator (mSaveButton, "clicked", accel_group,
- GDK_S, (GdkModifierType) GDK_CONTROL_MASK,
- GTK_ACCEL_VISIBLE);

mAddButton = gtk_button_new_from_stock ("gtk-add");
gtk_widget_show (mAddButton);
- gtk_container_add (GTK_CONTAINER (hbuttonbox1), mAddButton);
+ gtk_box_pack_start (GTK_BOX (hbuttonbox1), mAddButton, FALSE, TRUE, 0);
GTK_WIDGET_SET_FLAGS (mAddButton, GTK_CAN_DEFAULT);
- gtk_widget_add_accelerator (mAddButton, "clicked", accel_group,
- GDK_A, (GdkModifierType) GDK_CONTROL_MASK,
- GTK_ACCEL_VISIBLE);

mRemoveButton = gtk_button_new_from_stock ("gtk-delete");
gtk_widget_show (mRemoveButton);
- gtk_container_add (GTK_CONTAINER (hbuttonbox1), mRemoveButton);
+ gtk_box_pack_start (GTK_BOX (hbuttonbox1), mRemoveButton, FALSE, TRUE, 0);
GTK_WIDGET_SET_FLAGS (mRemoveButton, GTK_CAN_DEFAULT);
- gtk_widget_add_accelerator (mRemoveButton, "clicked", accel_group,
- GDK_R, (GdkModifierType) GDK_CONTROL_MASK,
- GTK_ACCEL_VISIBLE);
-// gtk_widget_add_accelerator (mRemoveButton, "clicked", accel_group,
-// GDK_Delete, (GdkModifierType) 0,
-// GTK_ACCEL_VISIBLE);
-
-/* // This button is obsolete
- mChangeModeButton = gtk_button_new_with_mnemonic (_("Add mode"));
- gtk_widget_show (mChangeModeButton);
- gtk_container_add (GTK_CONTAINER (hbuttonbox1), mChangeModeButton);
- GTK_WIDGET_SET_FLAGS (mChangeModeButton, GTK_CAN_DEFAULT);
- gtk_widget_add_accelerator (mChangeModeButton, "clicked", accel_group,
- GDK_M, (GdkModifierType) GDK_CONTROL_MASK,
- GTK_ACCEL_VISIBLE);
-*/

- mQuitButton = gtk_button_new_from_stock ("gtk-quit");
+ mQuitButton = gtk_button_new_from_stock ("gtk-close");
gtk_widget_show (mQuitButton);
- gtk_container_add (GTK_CONTAINER (hbuttonbox1), mQuitButton);
+ gtk_box_pack_end (GTK_BOX (hbuttonbox1), mQuitButton, FALSE, TRUE, 0);
GTK_WIDGET_SET_FLAGS (mQuitButton, GTK_CAN_DEFAULT);
- gtk_widget_add_accelerator (mQuitButton, "clicked", accel_group,
- GDK_Q, (GdkModifierType) GDK_CONTROL_MASK,
- GTK_ACCEL_VISIBLE);
-
- gtk_window_add_accel_group (GTK_WINDOW (mWindow), accel_group);
}

void KasumiMainWindow::createWordList()
@@ -213,8 +182,10 @@
"text",
COL_WORD,
NULL);
+ gtk_tree_view_column_set_min_width(mSpellingColumn, 80);
gtk_tree_view_column_set_resizable(mSpellingColumn, true);
-
gtk_tree_view_insert_column(GTK_TREE_VIEW(mWordListView),mSpellingColumn,-1);
+ gtk_tree_view_insert_column(GTK_TREE_VIEW(mWordListView),
+ mSpellingColumn, -1);

renderer = gtk_cell_renderer_text_new();
g_signal_connect(G_OBJECT(renderer), "edited",
@@ -227,6 +198,7 @@
"text",
COL_YOMI,
NULL);
+ gtk_tree_view_column_set_min_width(mSoundColumn, 80);
gtk_tree_view_column_set_resizable(mSoundColumn, true);
gtk_tree_view_insert_column(GTK_TREE_VIEW(mWordListView),mSoundColumn,-1);
gtk_tree_view_column_set_clickable(mSoundColumn,TRUE);
@@ -252,6 +224,7 @@
"text",
COL_FREQ,
NULL);
+ gtk_tree_view_column_set_min_width(mFreqColumn, 60);
gtk_tree_view_column_set_resizable(mFreqColumn, true);
gtk_tree_view_insert_column(GTK_TREE_VIEW(mWordListView),mFreqColumn,-1);
gtk_tree_view_column_set_clickable(mFreqColumn, TRUE);
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/KasumiWordType.cxx new/kasumi-2.5/KasumiWordType.cxx
--- old/kasumi-2.4/KasumiWordType.cxx 2006-10-14 11:35:00.000000000 +0200
+++ new/kasumi-2.5/KasumiWordType.cxx 2009-07-13 05:36:54.000000000 +0200
@@ -34,15 +34,21 @@
void KasumiWordType::initWordTypeList()
{
KasumiWordType::addNewWordType(_("Noun"), _("General Noun"), "#T35");
- KasumiWordType::addNewWordType(_("Noun"), _("Name of people"), "#JNM");
- KasumiWordType::addNewWordType(_("Noun"), _("Geographic Name"), "#CN");
- KasumiWordType::addNewWordType(_("Noun"), _("Corporate Name"), "#KK");
- KasumiWordType::addNewWordType(_("Noun"), _("SURU Connection"), "#T30");
+ KasumiWordType::addNewWordType(_("Noun"), _("followed by NA, SA and
SURU"), "#T00");
+ KasumiWordType::addNewWordType(_("Noun"), _("followed by NA and SA"),
"#T05");
+ KasumiWordType::addNewWordType(_("Noun"), _("followed by NA and SURU"),
"#T10");
+ KasumiWordType::addNewWordType(_("Noun"), _("followed by NA"), "#T15");
+ KasumiWordType::addNewWordType(_("Noun"), _("followed by SURU"), "#T30");
+ KasumiWordType::addNewWordType(_("Proper Noun"), _("Name of people"),
"#JN");
+ KasumiWordType::addNewWordType(_("Proper Noun"), _("Geographic Name"),
"#CN");
+ KasumiWordType::addNewWordType(_("Proper Noun"), _("Corporate Name"),
"#KK");
KasumiWordType::addNewWordType(_("Numeral"), "", "#NN");
- KasumiWordType::addNewWordType(_("Adjective (Keiyoushi)"), _("KU
Conjugation"), "#KY");
- KasumiWordType::addNewWordType(_("Adjective (Keiyoushi)"), _("SIKU
Conjugation"), "#KYT");
- KasumiWordType::addNewWordType(_("Adjective (Keiyoudoushi)"), "", "#T05");
- KasumiWordType::addNewWordType(_("Adverb"), "", "#F04");
+ KasumiWordType::addNewWordType(_("Adjective (Keiyoushi)"), "", "#KY");
+ KasumiWordType::addNewWordType(_("Adverb"), _("General Adverb"), "#F14");
+ KasumiWordType::addNewWordType(_("Adverb"), _("followed by TO and TARU"),
"#F02");
+ KasumiWordType::addNewWordType(_("Adverb"), _("followed by TO and SURU"),
"#F04");
+ KasumiWordType::addNewWordType(_("Adverb"), _("followed by TO"), "#F06");
+ KasumiWordType::addNewWordType(_("Adverb"), _("followed by SURU"), "#F12");
KasumiWordType::addNewWordType(_("Interjection"), "", "#CJ");
KasumiWordType::addNewWordType(_("Adnominal adjunct"), "", "#RT");
KasumiWordType::addNewWordType(_("Single Kanji Character"), "", "#KJ");
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/cellrendererspin.c new/kasumi-2.5/cellrendererspin.c
--- old/kasumi-2.4/cellrendererspin.c 2006-05-28 11:01:14.000000000 +0200
+++ new/kasumi-2.5/cellrendererspin.c 2009-07-13 07:47:19.000000000 +0200
@@ -284,7 +284,9 @@
static gboolean
onButtonPress (GtkWidget *spinbutton, GdkEventButton *bevent, gpointer data)
{
- if (bevent->button == 1 && bevent->type == GDK_2BUTTON_PRESS ||
bevent->type == GDK_3BUTTON_PRESS)
+ if (bevent->button == 1 &&
+ (bevent->type == GDK_2BUTTON_PRESS ||
+ bevent->type == GDK_3BUTTON_PRESS))
{
/* g_print ("double or triple click caught and ignored.\n");*/
return TRUE; /* don't invoke other handlers */
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/configure.in new/kasumi-2.5/configure.in
--- old/kasumi-2.4/configure.in 2009-01-20 08:16:20.000000000 +0100
+++ new/kasumi-2.5/configure.in 2009-07-13 05:41:26.000000000 +0200
@@ -1,6 +1,6 @@
dnl Process this file with autoconf to produce a configure script.
AC_INIT(main.cxx, 2.0)
-AM_INIT_AUTOMAKE(kasumi, 2.4)
+AM_INIT_AUTOMAKE(kasumi, 2.5)
AM_CONFIG_HEADER(config.h)

dnl Checks for programs.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/kasumi.1 new/kasumi-2.5/kasumi.1
--- old/kasumi-2.4/kasumi.1 2006-10-14 08:18:32.000000000 +0200
+++ new/kasumi-2.5/kasumi.1 2009-06-25 10:46:31.000000000 +0200
@@ -78,6 +78,3 @@

.PP
On Debian systems, the complete text of the GNU General Public License can be
found in /usr/share/common\-licenses/GPL\&.
-
-.SH AUTHOR
-Ikuya Awashiro.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/main.cxx new/kasumi-2.5/main.cxx
--- old/kasumi-2.4/main.cxx 2009-01-21 02:15:31.000000000 +0100
+++ new/kasumi-2.5/main.cxx 2009-07-13 07:47:19.000000000 +0200
@@ -88,8 +88,8 @@
static GtkTargetEntry targets[]={
{"STRING", 0, TARGET_STRING},
};
-static GdkAtom atom_kz0; /* for checking process */
-static GdkAtom atom_kz1; /* for sending arguments */
+static GdkAtom atom0; /* for checking process */
+static GdkAtom atom1; /* for sending arguments */
static gchar *arg_text = NULL;
static gint instance = -1;

@@ -102,13 +102,13 @@
gchar *text = NULL;
gint length = 0;

- if (data->selection == atom_kz0) {
+ if (data->selection == atom0) {
text = "Kasumi Selection";
length = strlen(text);
- gtk_selection_convert(window, atom_kz1,
+ gtk_selection_convert(window, atom1,
GDK_SELECTION_TYPE_STRING,
GDK_CURRENT_TIME);
- } else if (data->selection == atom_kz1 && arg_text != NULL) {
+ } else if (data->selection == atom1 && arg_text != NULL) {
text = arg_text;
arg_text = NULL;
length = strlen(text);
@@ -116,7 +116,7 @@

if (text != NULL) {
gtk_selection_data_set_text(data, text, length);
- if (data->selection == atom_kz1)
+ if (data->selection == atom1)
g_free(text);
}
}
@@ -126,9 +126,9 @@
guint time,
gpointer user_data)
{
- if (data->selection == atom_kz0) {
+ if (data->selection == atom0) {
instance = MAX(data->length, 0);
- } else if (data->selection == atom_kz1 && data->length > 0) {
+ } else if (data->selection == atom1 && data->length > 0) {
}
}

@@ -139,13 +139,13 @@

gtk_widget_realize(window);

- atom_kz0 = gdk_atom_intern("Kasumi InterProcess communication 0",
+ atom0 = gdk_atom_intern("Kasumi InterProcess communication 0",
FALSE);
- atom_kz1 = gdk_atom_intern("Kasumi InterProcess communication 1",
+ atom1 = gdk_atom_intern("Kasumi InterProcess communication 1",
FALSE);

- gtk_selection_add_targets(window, atom_kz0, targets, 1);
- gtk_selection_add_targets(window, atom_kz1, targets, 1);
+ gtk_selection_add_targets(window, atom0, targets, 1);
+ gtk_selection_add_targets(window, atom1, targets, 1);
g_signal_connect (window, "selection-get",
G_CALLBACK(cb_selection_get), window);
g_signal_connect (window, "selection-received",
@@ -163,9 +163,9 @@
}
if (length > 0) {
arg_text[length - 1] = '\0';
- gtk_selection_owner_set(window, atom_kz1, GDK_CURRENT_TIME);
+ gtk_selection_owner_set(window, atom1, GDK_CURRENT_TIME);
}
- gtk_selection_convert(window,atom_kz0,
+ gtk_selection_convert(window,atom0,
GDK_SELECTION_TYPE_STRING,
GDK_CURRENT_TIME);
while (instance < 0)
@@ -182,7 +182,7 @@
}
g_free(arg_text);
arg_text = NULL;
- gtk_selection_owner_set(window, atom_kz0, GDK_CURRENT_TIME);
+ gtk_selection_owner_set(window, atom0, GDK_CURRENT_TIME);

return window;
}
Files old/kasumi-2.4/po/it.gmo and new/kasumi-2.5/po/it.gmo differ
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/po/it.po new/kasumi-2.5/po/it.po
--- old/kasumi-2.4/po/it.po 2009-01-27 13:50:59.000000000 +0100
+++ new/kasumi-2.5/po/it.po 2009-07-21 11:18:58.000000000 +0200
@@ -7,7 +7,7 @@
msgstr ""
"Project-Id-Version: it\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2009-01-27 21:50+0900\n"
+"POT-Creation-Date: 2009-07-21 18:18+0900\n"
"PO-Revision-Date: 2006-06-25 13:04+0900\n"
"Last-Translator: Diego 'Flameeyes' Pettenò <flameeyes@xxxxxxxxxx>\n"
"Language-Team: Italian\n"
@@ -25,39 +25,39 @@
"Il suono deve contenere solo caratteri Hiragana. Sono stati inseriti "
"caratteri non validi."

-#: KasumiMainWindow.cxx:95
+#: KasumiMainWindow.cxx:81
msgid "Kasumi"
msgstr "Kasumi"

-#: KasumiMainWindow.cxx:114
-msgid "search"
-msgstr "cerca"
+#: KasumiMainWindow.cxx:106
+msgid "<b>Search:</b>"
+msgstr ""

-#: KasumiMainWindow.cxx:124
+#: KasumiMainWindow.cxx:118
msgid "Search by Spelling"
msgstr "Cerca per ortografia"

-#: KasumiMainWindow.cxx:130
+#: KasumiMainWindow.cxx:124
msgid "Search by Sound"
msgstr "Cerca per suono"

-#: KasumiMainWindow.cxx:211 KasumiAddWindow.cxx:70
+#: KasumiMainWindow.cxx:180 KasumiAddWindow.cxx:71
msgid "Spelling"
msgstr "Ortografia"

-#: KasumiMainWindow.cxx:225 KasumiAddWindow.cxx:83
+#: KasumiMainWindow.cxx:196 KasumiAddWindow.cxx:88
msgid "Sound"
msgstr "Suono"

-#: KasumiMainWindow.cxx:250 KasumiAddWindow.cxx:96
+#: KasumiMainWindow.cxx:222 KasumiAddWindow.cxx:105
msgid "Frequency"
msgstr "Frequenza"

-#: KasumiMainWindow.cxx:284
+#: KasumiMainWindow.cxx:257
msgid "WordClass"
msgstr "WordClass"

-#: KasumiMainWindow.cxx:402
+#: KasumiMainWindow.cxx:375
msgid ""
"Your dictionary was changed. Do you save these changes before Kasumi quits?"
msgstr ""
@@ -68,25 +68,20 @@
msgid "Kasumi (Register words)"
msgstr ""

-#: KasumiAddWindow.cxx:114
-#, fuzzy
-msgid "Word Type Category"
-msgstr "Tipo di parola"
-
-#: KasumiAddWindow.cxx:159
+#: KasumiAddWindow.cxx:127
msgid "Word Type"
msgstr "Tipo di parola"

-#: KasumiAddWindow.cxx:183 KasumiAddWindow.cxx:255
-msgid "Add"
-msgstr "Aggiungi"
+#: KasumiAddWindow.cxx:176
+msgid "Subcategory of Word Type"
+msgstr ""

-#: KasumiAddWindow.cxx:201
+#: KasumiAddWindow.cxx:209
#, fuzzy
msgid "Add entered word and quit registration."
msgstr "Salva il vocabolario ed esci da questa applicazione."

-#: KasumiAddWindow.cxx:202
+#: KasumiAddWindow.cxx:210
#, fuzzy
msgid ""
"If all the necessary items are filled in, add entered word and quit "
@@ -95,60 +90,48 @@
"Se tutti gli oggetti necessari sono stati riempiti, aggiungi la parola "
"inserita."

-#: KasumiAddWindow.cxx:205
-msgid "Cancel"
-msgstr ""
-
-#: KasumiAddWindow.cxx:223 KasumiAddWindow.cxx:224
+#: KasumiAddWindow.cxx:217 KasumiAddWindow.cxx:218
#, fuzzy
msgid "Cancel registration and quit."
msgstr "Salva il vocabolario ed esci da questa applicazione."

-#: KasumiAddWindow.cxx:233
-msgid "Quit"
-msgstr "Esci"
-
-#: KasumiAddWindow.cxx:251
-msgid "Quit this application"
-msgstr "Esci da questa applicazione"
-
-#: KasumiAddWindow.cxx:252
-msgid "Save dictionary and quit this application."
-msgstr "Salva il vocabolario ed esci da questa applicazione."
-
-#: KasumiAddWindow.cxx:273
+#: KasumiAddWindow.cxx:231
msgid "Add entered word"
msgstr "Aggiungi la parola inserita"

-#: KasumiAddWindow.cxx:274
+#: KasumiAddWindow.cxx:232
msgid "If all the necessary items are filled in, add entered word."
msgstr ""
"Se tutti gli oggetti necessari sono stati riempiti, aggiungi la parola "
"inserita."

-#: KasumiAddWindow.cxx:277
-msgid "Edit"
-msgstr "Modifica"
-
-#: KasumiAddWindow.cxx:295
+#: KasumiAddWindow.cxx:239
msgid "Manage mode"
msgstr "Modalità gestione"

-#: KasumiAddWindow.cxx:296
+#: KasumiAddWindow.cxx:240
msgid "Make the shift to manage mode to modify and remove registered words."
msgstr ""
"Passa a modalità gestione per modificare e rimuovere le parole registrate."

-#: KasumiAddWindow.cxx:347
+#: KasumiAddWindow.cxx:247
+msgid "Quit this application"
+msgstr "Esci da questa applicazione"
+
+#: KasumiAddWindow.cxx:248
+msgid "Save dictionary and quit this application."
+msgstr "Salva il vocabolario ed esci da questa applicazione."
+
+#: KasumiAddWindow.cxx:299
msgid "Invalid entry for Sound."
msgstr "Elemento per \"suono\" non valido."

-#: KasumiAddWindow.cxx:360
+#: KasumiAddWindow.cxx:312
msgid "Invalid entry for Spelling."
msgstr "Elemento per \"ortografia\" non valido. "

#: KasumiWordType.cxx:36 KasumiWordType.cxx:37 KasumiWordType.cxx:38
-#: KasumiWordType.cxx:39 KasumiWordType.cxx:40
+#: KasumiWordType.cxx:39 KasumiWordType.cxx:40 KasumiWordType.cxx:41
#, fuzzy
msgid "Noun"
msgstr "Suono"
@@ -158,105 +141,146 @@
msgstr ""

#: KasumiWordType.cxx:37
-msgid "Name of people"
+msgid "followed by NA, SA and SURU"
msgstr ""

#: KasumiWordType.cxx:38
-msgid "Geographic Name"
+msgid "followed by NA and SA"
msgstr ""

#: KasumiWordType.cxx:39
-msgid "Corporate Name"
+msgid "followed by NA and SURU"
msgstr ""

#: KasumiWordType.cxx:40
-msgid "SURU Connection"
+msgid "followed by NA"
msgstr ""

-#: KasumiWordType.cxx:41
-msgid "Numeral"
+#: KasumiWordType.cxx:41 KasumiWordType.cxx:51
+msgid "followed by SURU"
msgstr ""

-#: KasumiWordType.cxx:42 KasumiWordType.cxx:43
-msgid "Adjective (Keiyoushi)"
+#: KasumiWordType.cxx:42 KasumiWordType.cxx:43 KasumiWordType.cxx:44
+msgid "Proper Noun"
msgstr ""

#: KasumiWordType.cxx:42
-msgid "KU Conjugation"
+msgid "Name of people"
msgstr ""

#: KasumiWordType.cxx:43
-msgid "SIKU Conjugation"
+msgid "Geographic Name"
msgstr ""

#: KasumiWordType.cxx:44
-msgid "Adjective (Keiyoudoushi)"
+msgid "Corporate Name"
msgstr ""

#: KasumiWordType.cxx:45
-msgid "Adverb"
+msgid "Numeral"
msgstr ""

#: KasumiWordType.cxx:46
-msgid "Interjection"
+msgid "Adjective (Keiyoushi)"
+msgstr ""
+
+#: KasumiWordType.cxx:47 KasumiWordType.cxx:48 KasumiWordType.cxx:49
+#: KasumiWordType.cxx:50 KasumiWordType.cxx:51
+msgid "Adverb"
msgstr ""

#: KasumiWordType.cxx:47
-msgid "Adnominal adjunct"
+msgid "General Adverb"
msgstr ""

#: KasumiWordType.cxx:48
+msgid "followed by TO and TARU"
+msgstr ""
+
+#: KasumiWordType.cxx:49
+msgid "followed by TO and SURU"
+msgstr ""
+
+#: KasumiWordType.cxx:50
+msgid "followed by TO"
+msgstr ""
+
+#: KasumiWordType.cxx:52
+msgid "Interjection"
+msgstr ""
+
+#: KasumiWordType.cxx:53
+msgid "Adnominal adjunct"
+msgstr ""
+
+#: KasumiWordType.cxx:54
msgid "Single Kanji Character"
msgstr ""

-#: KasumiWordType.cxx:49 KasumiWordType.cxx:50 KasumiWordType.cxx:51
-#: KasumiWordType.cxx:52 KasumiWordType.cxx:53 KasumiWordType.cxx:54
#: KasumiWordType.cxx:55 KasumiWordType.cxx:56 KasumiWordType.cxx:57
+#: KasumiWordType.cxx:58 KasumiWordType.cxx:59 KasumiWordType.cxx:60
+#: KasumiWordType.cxx:61 KasumiWordType.cxx:62 KasumiWordType.cxx:63
msgid "Verb"
msgstr ""

-#: KasumiWordType.cxx:49 KasumiWordType.cxx:58
+#: KasumiWordType.cxx:55 KasumiWordType.cxx:64
msgid "Ka 5"
msgstr ""

-#: KasumiWordType.cxx:50 KasumiWordType.cxx:59
+#: KasumiWordType.cxx:56 KasumiWordType.cxx:65
msgid "Ga 5"
msgstr ""

-#: KasumiWordType.cxx:51 KasumiWordType.cxx:60
+#: KasumiWordType.cxx:57 KasumiWordType.cxx:66
msgid "Sa 5"
msgstr ""

-#: KasumiWordType.cxx:52 KasumiWordType.cxx:61
+#: KasumiWordType.cxx:58 KasumiWordType.cxx:67
msgid "Ta 5"
msgstr ""

-#: KasumiWordType.cxx:53 KasumiWordType.cxx:62
+#: KasumiWordType.cxx:59 KasumiWordType.cxx:68
msgid "Na 5"
msgstr ""

-#: KasumiWordType.cxx:54 KasumiWordType.cxx:63
+#: KasumiWordType.cxx:60 KasumiWordType.cxx:69
msgid "Ba 5"
msgstr ""

-#: KasumiWordType.cxx:55 KasumiWordType.cxx:64
+#: KasumiWordType.cxx:61 KasumiWordType.cxx:70
msgid "Ma 5"
msgstr ""

-#: KasumiWordType.cxx:56 KasumiWordType.cxx:65
+#: KasumiWordType.cxx:62 KasumiWordType.cxx:71
msgid "Ra 5"
msgstr ""

-#: KasumiWordType.cxx:57 KasumiWordType.cxx:66
+#: KasumiWordType.cxx:63 KasumiWordType.cxx:72
msgid "Wa 5"
msgstr ""

-#: KasumiWordType.cxx:58 KasumiWordType.cxx:59 KasumiWordType.cxx:60
-#: KasumiWordType.cxx:61 KasumiWordType.cxx:62 KasumiWordType.cxx:63
#: KasumiWordType.cxx:64 KasumiWordType.cxx:65 KasumiWordType.cxx:66
+#: KasumiWordType.cxx:67 KasumiWordType.cxx:68 KasumiWordType.cxx:69
+#: KasumiWordType.cxx:70 KasumiWordType.cxx:71 KasumiWordType.cxx:72
msgid "Verb*"
msgstr ""

+#~ msgid "search"
+#~ msgstr "cerca"
+
+#, fuzzy
+#~ msgid "Word Type Category"
+#~ msgstr "Tipo di parola"
+
+#~ msgid "Add"
+#~ msgstr "Aggiungi"
+
+#~ msgid "Quit"
+#~ msgstr "Esci"
+
+#~ msgid "Edit"
+#~ msgstr "Modifica"
+
#~ msgid "Cannot find a specific word. Search from first?"
#~ msgstr ""
#~ "Impossibile trovare una parola specifica. Si vuole cercare dall'inizio?"
Files old/kasumi-2.4/po/ja.gmo and new/kasumi-2.5/po/ja.gmo differ
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/po/ja.po new/kasumi-2.5/po/ja.po
--- old/kasumi-2.4/po/ja.po 2009-01-27 13:50:59.000000000 +0100
+++ new/kasumi-2.5/po/ja.po 2009-07-21 11:18:58.000000000 +0200
@@ -7,7 +7,7 @@
msgstr ""
"Project-Id-Version: 0.4.0\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2009-01-27 21:50+0900\n"
+"POT-Creation-Date: 2009-07-21 18:18+0900\n"
"PO-Revision-Date: 2006-10-15 22:30+0900\n"
"Last-Translator: Takashi Nakamoto <bluedwarf@xxxxxxxxxxxxxxxxx>\n"
"Language-Team: Takashi Nakamoto <bluedwarf@xxxxxxxxxxxxxxxxx>\n"
@@ -21,39 +21,39 @@
"character: "
msgstr "�ɤߤˤҤ餬�ʰʳ���ʸ�������Ϥ��뤳�ȤϤǤ��ޤ���: "

-#: KasumiMainWindow.cxx:95
+#: KasumiMainWindow.cxx:81
msgid "Kasumi"
msgstr "��"

-#: KasumiMainWindow.cxx:114
-msgid "search"
-msgstr "����"
+#: KasumiMainWindow.cxx:106
+msgid "<b>Search:</b>"
+msgstr "<b>����:</b>"

-#: KasumiMainWindow.cxx:124
+#: KasumiMainWindow.cxx:118
msgid "Search by Spelling"
msgstr "ñ���Ǹ���"

-#: KasumiMainWindow.cxx:130
+#: KasumiMainWindow.cxx:124
msgid "Search by Sound"
msgstr "�ɤߤǸ���"

-#: KasumiMainWindow.cxx:211 KasumiAddWindow.cxx:70
+#: KasumiMainWindow.cxx:180 KasumiAddWindow.cxx:71
msgid "Spelling"
msgstr "ñ��"

-#: KasumiMainWindow.cxx:225 KasumiAddWindow.cxx:83
+#: KasumiMainWindow.cxx:196 KasumiAddWindow.cxx:88
msgid "Sound"
msgstr "�ɤ�"

-#: KasumiMainWindow.cxx:250 KasumiAddWindow.cxx:96
+#: KasumiMainWindow.cxx:222 KasumiAddWindow.cxx:105
msgid "Frequency"
msgstr "����"

-#: KasumiMainWindow.cxx:284
+#: KasumiMainWindow.cxx:257
msgid "WordClass"
msgstr "�ʻ�"

-#: KasumiMainWindow.cxx:402
+#: KasumiMainWindow.cxx:375
msgid ""
"Your dictionary was changed. Do you save these changes before Kasumi quits?"
msgstr "�������ѹ����ä������ޤ�����������λ����������¸���ޤ�����"
@@ -63,23 +63,19 @@
msgstr "�� (ñ����Ͽ)"

# �ʻ���ʬ��
-#: KasumiAddWindow.cxx:114
-msgid "Word Type Category"
-msgstr "�ʻ���ʬ��"
-
-#: KasumiAddWindow.cxx:159
+#: KasumiAddWindow.cxx:127
msgid "Word Type"
msgstr "�ʻ�"

-#: KasumiAddWindow.cxx:183 KasumiAddWindow.cxx:255
-msgid "Add"
-msgstr "�ɲ�"
+#: KasumiAddWindow.cxx:176
+msgid "Subcategory of Word Type"
+msgstr "�ʻ��κ�ʬ��"

-#: KasumiAddWindow.cxx:201
+#: KasumiAddWindow.cxx:209
msgid "Add entered word and quit registration."
msgstr "���Ϥ��줿ñ������Ͽ����ñ����Ͽ����λ���ޤ���"

-#: KasumiAddWindow.cxx:202
+#: KasumiAddWindow.cxx:210
msgid ""
"If all the necessary items are filled in, add entered word and quit "
"registration."
@@ -87,56 +83,44 @@
"���Ƥ�ɬ�׻��ब���������Ƥ����顢���Ϥ��줿ñ������Ͽ����ñ����Ͽ�򤷤夦"
"���礦���ޤ���"

-#: KasumiAddWindow.cxx:205
-msgid "Cancel"
-msgstr "����"
-
-#: KasumiAddWindow.cxx:223 KasumiAddWindow.cxx:224
+#: KasumiAddWindow.cxx:217 KasumiAddWindow.cxx:218
msgid "Cancel registration and quit."
msgstr "ñ����Ͽ�����Ǥ��ޤ�"

-#: KasumiAddWindow.cxx:233
-msgid "Quit"
-msgstr "��λ"
-
-#: KasumiAddWindow.cxx:251
-msgid "Quit this application"
-msgstr "���Υ��ץꥱ������������λ����"
-
-#: KasumiAddWindow.cxx:252
-msgid "Save dictionary and quit this application."
-msgstr "��������¸���ơ����Υ��ץꥱ������������λ���ޤ���"
-
-#: KasumiAddWindow.cxx:273
+#: KasumiAddWindow.cxx:231
msgid "Add entered word"
msgstr "���Ϥ��줿ñ�����ɲä���"

-#: KasumiAddWindow.cxx:274
+#: KasumiAddWindow.cxx:232
msgid "If all the necessary items are filled in, add entered word."
msgstr "���Ƥ�ɬ�׻��ब���������Ƥ����顢���Ϥ��줿ñ�����ɲä��ޤ���"

-#: KasumiAddWindow.cxx:277
-msgid "Edit"
-msgstr "�Խ�"
-
-#: KasumiAddWindow.cxx:295
+#: KasumiAddWindow.cxx:239
msgid "Manage mode"
msgstr "���������⡼��"

-#: KasumiAddWindow.cxx:296
+#: KasumiAddWindow.cxx:240
msgid "Make the shift to manage mode to modify and remove registered words."
msgstr "ñ�����ѹ����������Ԥ��뼭�������⡼�ɤ˰ܹԤ��ޤ���"

-#: KasumiAddWindow.cxx:347
+#: KasumiAddWindow.cxx:247
+msgid "Quit this application"
+msgstr "���Υ��ץꥱ������������λ����"
+
+#: KasumiAddWindow.cxx:248
+msgid "Save dictionary and quit this application."
+msgstr "��������¸���ơ����Υ��ץꥱ������������λ���ޤ���"
+
+#: KasumiAddWindow.cxx:299
msgid "Invalid entry for Sound."
msgstr "���ɤߡפι��ܤ����������Ϥ��Ƥ�������"

-#: KasumiAddWindow.cxx:360
+#: KasumiAddWindow.cxx:312
msgid "Invalid entry for Spelling."
msgstr "��ñ���פι��ܤ����������Ϥ��Ƥ�������"

#: KasumiWordType.cxx:36 KasumiWordType.cxx:37 KasumiWordType.cxx:38
-#: KasumiWordType.cxx:39 KasumiWordType.cxx:40
+#: KasumiWordType.cxx:39 KasumiWordType.cxx:40 KasumiWordType.cxx:41
msgid "Noun"
msgstr "̾��"

@@ -145,105 +129,145 @@
msgstr "����̾��"

#: KasumiWordType.cxx:37
+msgid "followed by NA, SA and SURU"
+msgstr "�֤ʡס֤��ס֤����פ���³"
+
+#: KasumiWordType.cxx:38
+msgid "followed by NA and SA"
+msgstr "�֤ʡס֤��פ���³"
+
+#: KasumiWordType.cxx:39
+msgid "followed by NA and SURU"
+msgstr "�֤ʡס֤����פ���³"
+
+#: KasumiWordType.cxx:40
+msgid "followed by NA"
+msgstr "�֤ʡפ���³"
+
+#: KasumiWordType.cxx:41 KasumiWordType.cxx:51
+msgid "followed by SURU"
+msgstr "�֤����פ���³"
+
+#: KasumiWordType.cxx:42 KasumiWordType.cxx:43 KasumiWordType.cxx:44
+msgid "Proper Noun"
+msgstr "��ͭ̾��"
+
+#: KasumiWordType.cxx:42
msgid "Name of people"
msgstr "��̾"

-#: KasumiWordType.cxx:38
+#: KasumiWordType.cxx:43
msgid "Geographic Name"
msgstr "��̾"

-#: KasumiWordType.cxx:39
+#: KasumiWordType.cxx:44
msgid "Corporate Name"
msgstr "����̾"

-#: KasumiWordType.cxx:40
-msgid "SURU Connection"
-msgstr "������³"
-
-#: KasumiWordType.cxx:41
+#: KasumiWordType.cxx:45
msgid "Numeral"
msgstr "����"

-#: KasumiWordType.cxx:42 KasumiWordType.cxx:43
+#: KasumiWordType.cxx:46
msgid "Adjective (Keiyoushi)"
msgstr "���ƻ�"

-#: KasumiWordType.cxx:42
-msgid "KU Conjugation"
-msgstr "������"
+#: KasumiWordType.cxx:47 KasumiWordType.cxx:48 KasumiWordType.cxx:49
+#: KasumiWordType.cxx:50 KasumiWordType.cxx:51
+msgid "Adverb"
+msgstr "����"

-#: KasumiWordType.cxx:43
-msgid "SIKU Conjugation"
-msgstr "��������"
+#: KasumiWordType.cxx:47
+msgid "General Adverb"
+msgstr "����������"

-#: KasumiWordType.cxx:44
-msgid "Adjective (Keiyoudoushi)"
-msgstr "����ư��"
+#: KasumiWordType.cxx:48
+msgid "followed by TO and TARU"
+msgstr "�֤ȡס֤����פ���³"

-#: KasumiWordType.cxx:45
-msgid "Adverb"
-msgstr "����"
+#: KasumiWordType.cxx:49
+msgid "followed by TO and SURU"
+msgstr "�֤ȡס֤����פ���³"
+
+#: KasumiWordType.cxx:50
+msgid "followed by TO"
+msgstr "�֤ȡפ���³"

-#: KasumiWordType.cxx:46
+#: KasumiWordType.cxx:52
msgid "Interjection"
-msgstr "��ư��"
+msgstr "��ư�졦��³��"

-#: KasumiWordType.cxx:47
+#: KasumiWordType.cxx:53
msgid "Adnominal adjunct"
msgstr "Ϣ�λ�"

-#: KasumiWordType.cxx:48
+#: KasumiWordType.cxx:54
msgid "Single Kanji Character"
msgstr "��"

-#: KasumiWordType.cxx:49 KasumiWordType.cxx:50 KasumiWordType.cxx:51
-#: KasumiWordType.cxx:52 KasumiWordType.cxx:53 KasumiWordType.cxx:54
#: KasumiWordType.cxx:55 KasumiWordType.cxx:56 KasumiWordType.cxx:57
+#: KasumiWordType.cxx:58 KasumiWordType.cxx:59 KasumiWordType.cxx:60
+#: KasumiWordType.cxx:61 KasumiWordType.cxx:62 KasumiWordType.cxx:63
msgid "Verb"
msgstr "ư��"

-#: KasumiWordType.cxx:49 KasumiWordType.cxx:58
+#: KasumiWordType.cxx:55 KasumiWordType.cxx:64
msgid "Ka 5"
msgstr "����5��"

-#: KasumiWordType.cxx:50 KasumiWordType.cxx:59
+#: KasumiWordType.cxx:56 KasumiWordType.cxx:65
msgid "Ga 5"
msgstr "����5��"

-#: KasumiWordType.cxx:51 KasumiWordType.cxx:60
+#: KasumiWordType.cxx:57 KasumiWordType.cxx:66
msgid "Sa 5"
msgstr "����5��"

-#: KasumiWordType.cxx:52 KasumiWordType.cxx:61
+#: KasumiWordType.cxx:58 KasumiWordType.cxx:67
msgid "Ta 5"
msgstr "����5��"

-#: KasumiWordType.cxx:53 KasumiWordType.cxx:62
+#: KasumiWordType.cxx:59 KasumiWordType.cxx:68
msgid "Na 5"
msgstr "�ʹ�5��"

-#: KasumiWordType.cxx:54 KasumiWordType.cxx:63
+#: KasumiWordType.cxx:60 KasumiWordType.cxx:69
msgid "Ba 5"
msgstr "�й�5��"

-#: KasumiWordType.cxx:55 KasumiWordType.cxx:64
+#: KasumiWordType.cxx:61 KasumiWordType.cxx:70
msgid "Ma 5"
msgstr "�޹�5��"

-#: KasumiWordType.cxx:56 KasumiWordType.cxx:65
+#: KasumiWordType.cxx:62 KasumiWordType.cxx:71
msgid "Ra 5"
msgstr "����5��"

-#: KasumiWordType.cxx:57 KasumiWordType.cxx:66
+#: KasumiWordType.cxx:63 KasumiWordType.cxx:72
msgid "Wa 5"
msgstr "����5��"

-#: KasumiWordType.cxx:58 KasumiWordType.cxx:59 KasumiWordType.cxx:60
-#: KasumiWordType.cxx:61 KasumiWordType.cxx:62 KasumiWordType.cxx:63
#: KasumiWordType.cxx:64 KasumiWordType.cxx:65 KasumiWordType.cxx:66
+#: KasumiWordType.cxx:67 KasumiWordType.cxx:68 KasumiWordType.cxx:69
+#: KasumiWordType.cxx:70 KasumiWordType.cxx:71 KasumiWordType.cxx:72
msgid "Verb*"
msgstr "ư�� (Ϣ�ѷ���̾��)"

+#~ msgid "Add"
+#~ msgstr "�ɲ�"
+
+#~ msgid "Cancel"
+#~ msgstr "����"
+
+#~ msgid "Quit"
+#~ msgstr "��λ"
+
+#~ msgid "Edit"
+#~ msgstr "�Խ�"
+
+#~ msgid "search"
+#~ msgstr "����"
+
#~ msgid "Cannot find a specific word. Search from first?"
#~ msgstr "����Ƥ⸫�Ĥ����ޤ����Ǥ������ǽ餫�鸡��ޤ�����"



++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++



Remember to have fun...

diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' --exclude Makefile.in --exclude configure --exclude
config.guess --exclude '*.pot' --exclude mkinstalldirs --exclude aclocal.m4
--exclude config.sub --exclude depcomp --exclude install-sh --exclude ltmain.sh
old/kasumi-2.4/KasumiAddWindow.cxx new/kasumi-2.5/KasumiAddWindow.cxx
--- old/kasumi-2.4/KasumiAddWindow.cxx 2009-01-21 02:15:31.000000000 +0100
+++ new/kasumi-2.5/KasumiAddWindow.cxx 2009-07-21 10:59:46.000000000 +0200
@@ -64,11 +64,13 @@

// creating vbox for text entries, spin button and so on.
GtkWidget *vbox = gtk_vbox_new(FALSE,0);
+ gtk_container_set_border_width(GTK_CONTAINER(vbox), 6);
gtk_container_add(GTK_CONTAINER(window),vbox);

// creating text entries for "Spelling"
GtkWidget *label = gtk_label_new(_("Spelling"));
- GtkWidget *alignment = gtk_alignment_new(0,0.5,0,0);
+ GtkWidget *alignment = gtk_alignment_new(0, 0.5, 0, 0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0, 6, 6);
gtk_container_add(GTK_CONTAINER(alignment),GTK_WIDGET(label));
gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);

@@ -77,11 +79,15 @@
if (IsEUCJP) spelling = KasumiWord::convertEUCJPToUTF8(spelling);
gtk_entry_set_text(GTK_ENTRY(SpellingEntry),
spelling.c_str());
- gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(SpellingEntry),FALSE,FALSE,0);
+ alignment = gtk_alignment_new(0, 0.5, 1.0, 1.0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 6, 6, 6);
+ gtk_container_add(GTK_CONTAINER(alignment), SpellingEntry);
+ gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);

// creating text entries for "Sound"
label = gtk_label_new(_("Sound"));
- alignment = gtk_alignment_new(0,0.5,0,0);
+ alignment = gtk_alignment_new(0, 0.5, 0, 0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0, 6, 6);
gtk_container_add(GTK_CONTAINER(alignment),GTK_WIDGET(label));
gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);

@@ -90,11 +96,15 @@
if (IsEUCJP) sound = KasumiWord::convertEUCJPToUTF8(sound);
gtk_entry_set_text(GTK_ENTRY(SoundEntry),
sound.c_str());
- gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(SoundEntry),FALSE,FALSE,0);
+ alignment = gtk_alignment_new(0, 0.5, 1.0, 1.0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 6, 6, 6);
+ gtk_container_add(GTK_CONTAINER(alignment), SoundEntry);
+ gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);

// creating spin button for "Frequency"
label = gtk_label_new(_("Frequency"));
- alignment = gtk_alignment_new(0,0.5,0,0);
+ alignment = gtk_alignment_new(0, 0.5, 0, 0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0, 6, 6);
gtk_container_add(GTK_CONTAINER(alignment),GTK_WIDGET(label));
gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);

@@ -108,11 +118,15 @@
FREQ_UBOUND / 100
,0);
FrequencySpin = gtk_spin_button_new(GTK_ADJUSTMENT(adjustment),1.0,0);
- gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(FrequencySpin),FALSE,FALSE,0);
+ alignment = gtk_alignment_new(0, 0.5, 1.0, 1.0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 6, 6, 6);
+ gtk_container_add(GTK_CONTAINER(alignment), FrequencySpin);
+ gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);

- // creating combo box for "Word Type Category"
- label = gtk_label_new(_("Word Type Category"));
- alignment = gtk_alignment_new(0,0.5,0,0);
+ // creating combo box for "Word Type"
+ label = gtk_label_new(_("Word Type"));
+ alignment = gtk_alignment_new(0, 0.5, 0, 0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0, 6, 6);
gtk_container_add(GTK_CONTAINER(alignment),GTK_WIDGET(label));
gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);

@@ -149,15 +163,19 @@
"text", COL_UI_STRING,
NULL);
gtk_combo_box_set_active_iter(GTK_COMBO_BOX(WordTypeCategoryCombo),
&defaultWordTypeCategoryIter);
+ alignment = gtk_alignment_new(0, 0.5, 1.0, 1.0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 6, 6, 6);
+ gtk_container_add(GTK_CONTAINER(alignment), WordTypeCategoryCombo);
gtk_box_pack_start(GTK_BOX(vbox),
- GTK_WIDGET(WordTypeCategoryCombo),FALSE,FALSE,0);
+ GTK_WIDGET(alignment),FALSE,FALSE,0);
g_signal_connect(G_OBJECT(WordTypeCategoryCombo),"changed",
G_CALLBACK(_call_back_word_type_category_changed),this);


- // creating combo box for "Word Type"
- label = gtk_label_new(_("Word Type"));
- alignment = gtk_alignment_new(0,0.5,0,0);
+ // creating combo box for "Subcategory of Word Type"
+ label = gtk_label_new(_("Subcategory of Word Type"));
+ alignment = gtk_alignment_new(0, 0.5, 0, 0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0, 6, 6);
gtk_container_add(GTK_CONTAINER(alignment),GTK_WIDGET(label));
gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);

@@ -168,57 +186,33 @@
gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(WordTypeCombo), renderer,
"text", COL_UI_STRING,
NULL);
+ alignment = gtk_alignment_new(0, 0.5, 1.0, 1.0);
+ gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 12, 6, 6);
+ gtk_container_add(GTK_CONTAINER(alignment), WordTypeCombo);
gtk_box_pack_start(GTK_BOX(vbox),
- GTK_WIDGET(WordTypeCombo),FALSE,FALSE,0);
+ GTK_WIDGET(alignment),FALSE,FALSE,0);
ChangeWordTypeList(true);

// creating box for buttons
GtkWidget *hbutton_box = gtk_hbutton_box_new();
+ gtk_box_set_spacing(GTK_BOX(hbutton_box),6);

gtk_button_box_set_layout(GTK_BUTTON_BOX(hbutton_box),GTK_BUTTONBOX_SPREAD);
- gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(hbutton_box),FALSE,FALSE,0);
+ gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(hbutton_box),FALSE,FALSE,6);

if( conf->getPropertyValue("StartupMode") == "EXCLUSIVE" )
{
- GtkWidget *button = gtk_button_new();
- label = gtk_label_new(_("Add"));
- GtkWidget *button_image = gtk_image_new_from_stock(GTK_STOCK_ADD,
- GTK_ICON_SIZE_BUTTON);
- GtkWidget *in_box = gtk_hbox_new(FALSE, 0);
- gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
- gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
- gtk_container_add(GTK_CONTAINER(button),in_box);
+ GtkWidget *button = gtk_button_new_from_stock(GTK_STOCK_ADD);
gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
g_signal_connect(G_OBJECT(button),"clicked",
G_CALLBACK(_call_back_add_window_add),this);
- GtkAccelGroup *accel = gtk_accel_group_new();
- gtk_window_add_accel_group(GTK_WINDOW(window), accel);
- string key = string("Ctrl+A");
- gtk_widget_add_accelerator(button, "clicked", accel,
- getAccelKey(key),
- getModifierType(key),
- GTK_ACCEL_VISIBLE);
gtk_tooltips_set_tip(Tooltips, button,
_("Add entered word and quit registration."),
_("If all the necessary items are filled in, add
entered word and quit registration."));

- button = gtk_button_new();
- label = gtk_label_new(_("Cancel"));
- button_image = gtk_image_new_from_stock(GTK_STOCK_QUIT,
- GTK_ICON_SIZE_BUTTON);
- in_box = gtk_hbox_new(FALSE, 0);
- gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
- gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
- gtk_container_add(GTK_CONTAINER(button),in_box);
+ button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
g_signal_connect(G_OBJECT(button),"clicked",
G_CALLBACK(_call_back_add_window_quit),this);
- accel = gtk_accel_group_new();
- gtk_window_add_accel_group(GTK_WINDOW(window), accel);
- key = string("Ctrl+C");
- gtk_widget_add_accelerator(button, "clicked", accel,
- getAccelKey(key),
- getModifierType(key),
- GTK_ACCEL_VISIBLE);
gtk_tooltips_set_tip(Tooltips, button,
_("Cancel registration and quit."),
_("Cancel registration and quit."));
@@ -229,72 +223,30 @@
{
// ADD mode
// creating buttons and configure shortcut key
- GtkWidget *button = gtk_button_new();
- label = gtk_label_new(_("Quit"));
- GtkWidget *button_image = gtk_image_new_from_stock(GTK_STOCK_QUIT,
-
GTK_ICON_SIZE_BUTTON);
- GtkWidget *in_box = gtk_hbox_new(FALSE, 0);
- gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
- gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
- gtk_container_add(GTK_CONTAINER(button),in_box);
- gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
- g_signal_connect(G_OBJECT(button),"clicked",
- G_CALLBACK(_call_back_add_window_quit),this);
- GtkAccelGroup *accel = gtk_accel_group_new();
- gtk_window_add_accel_group(GTK_WINDOW(window), accel);
- string key = string("Ctrl+Q");
- gtk_widget_add_accelerator(button, "clicked", accel,
- getAccelKey(key),
- getModifierType(key),
- GTK_ACCEL_VISIBLE);
- gtk_tooltips_set_tip(Tooltips, button,
- _("Quit this application"),
- _("Save dictionary and quit this application."));
-
- button = gtk_button_new();
- label = gtk_label_new(_("Add"));
- button_image = gtk_image_new_from_stock(GTK_STOCK_ADD,
- GTK_ICON_SIZE_BUTTON);
- in_box = gtk_hbox_new(FALSE, 0);
- gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
- gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
- gtk_container_add(GTK_CONTAINER(button),in_box);
+ GtkWidget *button = gtk_button_new_from_stock(GTK_STOCK_ADD);
gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
g_signal_connect(G_OBJECT(button),"clicked",
G_CALLBACK(_call_back_add_window_add),this);
- accel = gtk_accel_group_new();
- gtk_window_add_accel_group(GTK_WINDOW(window), accel);
- key = string("Ctrl+A");
- gtk_widget_add_accelerator(button, "clicked", accel,
- getAccelKey(key),
- getModifierType(key),
- GTK_ACCEL_VISIBLE);
gtk_tooltips_set_tip(Tooltips, button,
_("Add entered word"),
_("If all the necessary items are filled in, add
entered word."));

- button = gtk_button_new();
- label = gtk_label_new(_("Edit"));
- button_image = gtk_image_new_from_stock(GTK_STOCK_FIND_AND_REPLACE,
- GTK_ICON_SIZE_BUTTON);
- in_box = gtk_hbox_new(FALSE, 0);
- gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
- gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
- gtk_container_add(GTK_CONTAINER(button),in_box);
+ button = gtk_button_new_from_stock(GTK_STOCK_EDIT);
gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
g_signal_connect(G_OBJECT(button),"clicked",
G_CALLBACK(_call_back_manage_mode),this);
- accel = gtk_accel_group_new();
- gtk_window_add_accel_group(GTK_WINDOW(window), accel);
- key = string("Ctrl+M");
- gtk_widget_add_accelerator(button, "clicked", accel,
- getAccelKey(key),
- getModifierType(key),
- GTK_ACCEL_VISIBLE);
gtk_tooltips_set_tip(Tooltips, button,
_("Manage mode"),
_("Make the shift to manage mode to modify and
remove registered words."));

+ button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+ gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
+ g_signal_connect(G_OBJECT(button),"clicked",
+ G_CALLBACK(_call_back_add_window_quit),this);
+ gtk_tooltips_set_tip(Tooltips, button,
+ _("Quit this application"),
+ _("Save dictionary and quit this application."));
+
// get selection at the time of launching
g_signal_connect(G_OBJECT(SpellingEntry),"selection_received",
G_CALLBACK(_call_back_selection_data_received),NULL);
--
To unsubscribe, e-mail: opensuse-commit+unsubscribe@xxxxxxxxxxxx
For additional commands, e-mail: opensuse-commit+help@xxxxxxxxxxxx

< Previous Next >
This Thread
  • No further messages